# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class CableDesignConnectionListObject(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cable_design': 'ItemDomainCableDesign',
        'item_connector': 'ItemConnector',
        'cable_relationship': 'ItemElementRelationship',
        'md_item': 'ItemDomainMachineDesign',
        'md_connector': 'ItemConnector',
        'item_connector_name': 'str',
        'md_item_name': 'str',
        'md_connector_name': 'str'
    }

    attribute_map = {
        'cable_design': 'cableDesign',
        'item_connector': 'itemConnector',
        'cable_relationship': 'cableRelationship',
        'md_item': 'mdItem',
        'md_connector': 'mdConnector',
        'item_connector_name': 'itemConnectorName',
        'md_item_name': 'mdItemName',
        'md_connector_name': 'mdConnectorName'
    }

    def __init__(self, cable_design=None, item_connector=None, cable_relationship=None, md_item=None, md_connector=None, item_connector_name=None, md_item_name=None, md_connector_name=None, local_vars_configuration=None):  # noqa: E501
        """CableDesignConnectionListObject - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cable_design = None
        self._item_connector = None
        self._cable_relationship = None
        self._md_item = None
        self._md_connector = None
        self._item_connector_name = None
        self._md_item_name = None
        self._md_connector_name = None
        self.discriminator = None

        if cable_design is not None:
            self.cable_design = cable_design
        if item_connector is not None:
            self.item_connector = item_connector
        if cable_relationship is not None:
            self.cable_relationship = cable_relationship
        if md_item is not None:
            self.md_item = md_item
        if md_connector is not None:
            self.md_connector = md_connector
        if item_connector_name is not None:
            self.item_connector_name = item_connector_name
        if md_item_name is not None:
            self.md_item_name = md_item_name
        if md_connector_name is not None:
            self.md_connector_name = md_connector_name

    @property
    def cable_design(self):
        """Gets the cable_design of this CableDesignConnectionListObject.  # noqa: E501


        :return: The cable_design of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: ItemDomainCableDesign
        """
        return self._cable_design

    @cable_design.setter
    def cable_design(self, cable_design):
        """Sets the cable_design of this CableDesignConnectionListObject.


        :param cable_design: The cable_design of this CableDesignConnectionListObject.  # noqa: E501
        :type: ItemDomainCableDesign
        """

        self._cable_design = cable_design

    @property
    def item_connector(self):
        """Gets the item_connector of this CableDesignConnectionListObject.  # noqa: E501


        :return: The item_connector of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: ItemConnector
        """
        return self._item_connector

    @item_connector.setter
    def item_connector(self, item_connector):
        """Sets the item_connector of this CableDesignConnectionListObject.


        :param item_connector: The item_connector of this CableDesignConnectionListObject.  # noqa: E501
        :type: ItemConnector
        """

        self._item_connector = item_connector

    @property
    def cable_relationship(self):
        """Gets the cable_relationship of this CableDesignConnectionListObject.  # noqa: E501


        :return: The cable_relationship of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: ItemElementRelationship
        """
        return self._cable_relationship

    @cable_relationship.setter
    def cable_relationship(self, cable_relationship):
        """Sets the cable_relationship of this CableDesignConnectionListObject.


        :param cable_relationship: The cable_relationship of this CableDesignConnectionListObject.  # noqa: E501
        :type: ItemElementRelationship
        """

        self._cable_relationship = cable_relationship

    @property
    def md_item(self):
        """Gets the md_item of this CableDesignConnectionListObject.  # noqa: E501


        :return: The md_item of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: ItemDomainMachineDesign
        """
        return self._md_item

    @md_item.setter
    def md_item(self, md_item):
        """Sets the md_item of this CableDesignConnectionListObject.


        :param md_item: The md_item of this CableDesignConnectionListObject.  # noqa: E501
        :type: ItemDomainMachineDesign
        """

        self._md_item = md_item

    @property
    def md_connector(self):
        """Gets the md_connector of this CableDesignConnectionListObject.  # noqa: E501


        :return: The md_connector of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: ItemConnector
        """
        return self._md_connector

    @md_connector.setter
    def md_connector(self, md_connector):
        """Sets the md_connector of this CableDesignConnectionListObject.


        :param md_connector: The md_connector of this CableDesignConnectionListObject.  # noqa: E501
        :type: ItemConnector
        """

        self._md_connector = md_connector

    @property
    def item_connector_name(self):
        """Gets the item_connector_name of this CableDesignConnectionListObject.  # noqa: E501


        :return: The item_connector_name of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: str
        """
        return self._item_connector_name

    @item_connector_name.setter
    def item_connector_name(self, item_connector_name):
        """Sets the item_connector_name of this CableDesignConnectionListObject.


        :param item_connector_name: The item_connector_name of this CableDesignConnectionListObject.  # noqa: E501
        :type: str
        """

        self._item_connector_name = item_connector_name

    @property
    def md_item_name(self):
        """Gets the md_item_name of this CableDesignConnectionListObject.  # noqa: E501


        :return: The md_item_name of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: str
        """
        return self._md_item_name

    @md_item_name.setter
    def md_item_name(self, md_item_name):
        """Sets the md_item_name of this CableDesignConnectionListObject.


        :param md_item_name: The md_item_name of this CableDesignConnectionListObject.  # noqa: E501
        :type: str
        """

        self._md_item_name = md_item_name

    @property
    def md_connector_name(self):
        """Gets the md_connector_name of this CableDesignConnectionListObject.  # noqa: E501


        :return: The md_connector_name of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: str
        """
        return self._md_connector_name

    @md_connector_name.setter
    def md_connector_name(self, md_connector_name):
        """Sets the md_connector_name of this CableDesignConnectionListObject.


        :param md_connector_name: The md_connector_name of this CableDesignConnectionListObject.  # noqa: E501
        :type: str
        """

        self._md_connector_name = md_connector_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CableDesignConnectionListObject):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CableDesignConnectionListObject):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class ApiExceptionMessageExceptionCause(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'stack_trace': 'list[ApiExceptionMessageExceptionCauseStackTrace]',
        'message': 'str',
        'suppressed': 'list[ApiExceptionMessageExceptionCauseSuppressed]',
        'localized_message': 'str'
    }

    attribute_map = {
        'stack_trace': 'stackTrace',
        'message': 'message',
        'suppressed': 'suppressed',
        'localized_message': 'localizedMessage'
    }

    def __init__(self, stack_trace=None, message=None, suppressed=None, localized_message=None, local_vars_configuration=None):  # noqa: E501
        """ApiExceptionMessageExceptionCause - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._stack_trace = None
        self._message = None
        self._suppressed = None
        self._localized_message = None
        self.discriminator = None

        if stack_trace is not None:
            self.stack_trace = stack_trace
        if message is not None:
            self.message = message
        if suppressed is not None:
            self.suppressed = suppressed
        if localized_message is not None:
            self.localized_message = localized_message

    @property
    def stack_trace(self):
        """Gets the stack_trace of this ApiExceptionMessageExceptionCause.  # noqa: E501


        :return: The stack_trace of this ApiExceptionMessageExceptionCause.  # noqa: E501
        :rtype: list[ApiExceptionMessageExceptionCauseStackTrace]
        """
        return self._stack_trace

    @stack_trace.setter
    def stack_trace(self, stack_trace):
        """Sets the stack_trace of this ApiExceptionMessageExceptionCause.


        :param stack_trace: The stack_trace of this ApiExceptionMessageExceptionCause.  # noqa: E501
        :type: list[ApiExceptionMessageExceptionCauseStackTrace]
        """

        self._stack_trace = stack_trace

    @property
    def message(self):
        """Gets the message of this ApiExceptionMessageExceptionCause.  # noqa: E501


        :return: The message of this ApiExceptionMessageExceptionCause.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ApiExceptionMessageExceptionCause.


        :param message: The message of this ApiExceptionMessageExceptionCause.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def suppressed(self):
        """Gets the suppressed of this ApiExceptionMessageExceptionCause.  # noqa: E501


        :return: The suppressed of this ApiExceptionMessageExceptionCause.  # noqa: E501
        :rtype: list[ApiExceptionMessageExceptionCauseSuppressed]
        """
        return self._suppressed

    @suppressed.setter
    def suppressed(self, suppressed):
        """Sets the suppressed of this ApiExceptionMessageExceptionCause.


        :param suppressed: The suppressed of this ApiExceptionMessageExceptionCause.  # noqa: E501
        :type: list[ApiExceptionMessageExceptionCauseSuppressed]
        """

        self._suppressed = suppressed

    @property
    def localized_message(self):
        """Gets the localized_message of this ApiExceptionMessageExceptionCause.  # noqa: E501


        :return: The localized_message of this ApiExceptionMessageExceptionCause.  # noqa: E501
        :rtype: str
        """
        return self._localized_message

    @localized_message.setter
    def localized_message(self, localized_message):
        """Sets the localized_message of this ApiExceptionMessageExceptionCause.


        :param localized_message: The localized_message of this ApiExceptionMessageExceptionCause.  # noqa: E501
        :type: str
        """

        self._localized_message = localized_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiExceptionMessageExceptionCause):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApiExceptionMessageExceptionCause):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class RepresentingAssemblyElementForMachineInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'machine_id': 'int',
        'assembly_element_id': 'int',
        'template_match_by_name_for_custom_build': 'bool'
    }

    attribute_map = {
        'machine_id': 'machineId',
        'assembly_element_id': 'assemblyElementId',
        'template_match_by_name_for_custom_build': 'templateMatchByNameForCustomBuild'
    }

    def __init__(self, machine_id=None, assembly_element_id=None, template_match_by_name_for_custom_build=None, local_vars_configuration=None):  # noqa: E501
        """RepresentingAssemblyElementForMachineInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._machine_id = None
        self._assembly_element_id = None
        self._template_match_by_name_for_custom_build = None
        self.discriminator = None

        if machine_id is not None:
            self.machine_id = machine_id
        if assembly_element_id is not None:
            self.assembly_element_id = assembly_element_id
        if template_match_by_name_for_custom_build is not None:
            self.template_match_by_name_for_custom_build = template_match_by_name_for_custom_build

    @property
    def machine_id(self):
        """Gets the machine_id of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501


        :return: The machine_id of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501
        :rtype: int
        """
        return self._machine_id

    @machine_id.setter
    def machine_id(self, machine_id):
        """Sets the machine_id of this RepresentingAssemblyElementForMachineInformation.


        :param machine_id: The machine_id of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501
        :type: int
        """

        self._machine_id = machine_id

    @property
    def assembly_element_id(self):
        """Gets the assembly_element_id of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501


        :return: The assembly_element_id of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501
        :rtype: int
        """
        return self._assembly_element_id

    @assembly_element_id.setter
    def assembly_element_id(self, assembly_element_id):
        """Sets the assembly_element_id of this RepresentingAssemblyElementForMachineInformation.


        :param assembly_element_id: The assembly_element_id of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501
        :type: int
        """

        self._assembly_element_id = assembly_element_id

    @property
    def template_match_by_name_for_custom_build(self):
        """Gets the template_match_by_name_for_custom_build of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501


        :return: The template_match_by_name_for_custom_build of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501
        :rtype: bool
        """
        return self._template_match_by_name_for_custom_build

    @template_match_by_name_for_custom_build.setter
    def template_match_by_name_for_custom_build(self, template_match_by_name_for_custom_build):
        """Sets the template_match_by_name_for_custom_build of this RepresentingAssemblyElementForMachineInformation.


        :param template_match_by_name_for_custom_build: The template_match_by_name_for_custom_build of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501
        :type: bool
        """

        self._template_match_by_name_for_custom_build = template_match_by_name_for_custom_build

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RepresentingAssemblyElementForMachineInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RepresentingAssemblyElementForMachineInformation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class ItemConnector(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'label': 'str',
        'quantity': 'int',
        'property_value_list': 'list[PropertyValue]',
        'item': 'Item',
        'connector': 'Connector',
        'item_element_relationship_history_list': 'list[ItemElementRelationshipHistory]',
        'item_element_relationship_history_list1': 'list[ItemElementRelationshipHistory]',
        'item_resource_list': 'list[ItemResource]',
        'item_element_relationship_list': 'list[ItemElementRelationship]',
        'item_element_relationship_list1': 'list[ItemElementRelationship]',
        'item_connector_of_item_connected_to': 'ItemConnector',
        'item_connected_via': 'Item',
        'connectors_to_update': 'list[Connector]',
        'connectors_to_remove': 'list[Connector]',
        'connected': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'label': 'label',
        'quantity': 'quantity',
        'property_value_list': 'propertyValueList',
        'item': 'item',
        'connector': 'connector',
        'item_element_relationship_history_list': 'itemElementRelationshipHistoryList',
        'item_element_relationship_history_list1': 'itemElementRelationshipHistoryList1',
        'item_resource_list': 'itemResourceList',
        'item_element_relationship_list': 'itemElementRelationshipList',
        'item_element_relationship_list1': 'itemElementRelationshipList1',
        'item_connector_of_item_connected_to': 'itemConnectorOfItemConnectedTo',
        'item_connected_via': 'itemConnectedVia',
        'connectors_to_update': 'connectorsToUpdate',
        'connectors_to_remove': 'connectorsToRemove',
        'connected': 'connected'
    }

    def __init__(self, id=None, label=None, quantity=None, property_value_list=None, item=None, connector=None, item_element_relationship_history_list=None, item_element_relationship_history_list1=None, item_resource_list=None, item_element_relationship_list=None, item_element_relationship_list1=None, item_connector_of_item_connected_to=None, item_connected_via=None, connectors_to_update=None, connectors_to_remove=None, connected=None, local_vars_configuration=None):  # noqa: E501
        """ItemConnector - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._label = None
        self._quantity = None
        self._property_value_list = None
        self._item = None
        self._connector = None
        self._item_element_relationship_history_list = None
        self._item_element_relationship_history_list1 = None
        self._item_resource_list = None
        self._item_element_relationship_list = None
        self._item_element_relationship_list1 = None
        self._item_connector_of_item_connected_to = None
        self._item_connected_via = None
        self._connectors_to_update = None
        self._connectors_to_remove = None
        self._connected = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if label is not None:
            self.label = label
        if quantity is not None:
            self.quantity = quantity
        if property_value_list is not None:
            self.property_value_list = property_value_list
        if item is not None:
            self.item = item
        if connector is not None:
            self.connector = connector
        if item_element_relationship_history_list is not None:
            self.item_element_relationship_history_list = item_element_relationship_history_list
        if item_element_relationship_history_list1 is not None:
            self.item_element_relationship_history_list1 = item_element_relationship_history_list1
        if item_resource_list is not None:
            self.item_resource_list = item_resource_list
        if item_element_relationship_list is not None:
            self.item_element_relationship_list = item_element_relationship_list
        if item_element_relationship_list1 is not None:
            self.item_element_relationship_list1 = item_element_relationship_list1
        if item_connector_of_item_connected_to is not None:
            self.item_connector_of_item_connected_to = item_connector_of_item_connected_to
        if item_connected_via is not None:
            self.item_connected_via = item_connected_via
        if connectors_to_update is not None:
            self.connectors_to_update = connectors_to_update
        if connectors_to_remove is not None:
            self.connectors_to_remove = connectors_to_remove
        if connected is not None:
            self.connected = connected

    @property
    def id(self):
        """Gets the id of this ItemConnector.  # noqa: E501


        :return: The id of this ItemConnector.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ItemConnector.


        :param id: The id of this ItemConnector.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def label(self):
        """Gets the label of this ItemConnector.  # noqa: E501


        :return: The label of this ItemConnector.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this ItemConnector.


        :param label: The label of this ItemConnector.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                label is not None and len(label) > 64):
            raise ValueError("Invalid value for `label`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                label is not None and len(label) < 0):
            raise ValueError("Invalid value for `label`, length must be greater than or equal to `0`")  # noqa: E501

        self._label = label

    @property
    def quantity(self):
        """Gets the quantity of this ItemConnector.  # noqa: E501


        :return: The quantity of this ItemConnector.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this ItemConnector.


        :param quantity: The quantity of this ItemConnector.  # noqa: E501
        :type: int
        """

        self._quantity = quantity

    @property
    def property_value_list(self):
        """Gets the property_value_list of this ItemConnector.  # noqa: E501


        :return: The property_value_list of this ItemConnector.  # noqa: E501
        :rtype: list[PropertyValue]
        """
        return self._property_value_list

    @property_value_list.setter
    def property_value_list(self, property_value_list):
        """Sets the property_value_list of this ItemConnector.


        :param property_value_list: The property_value_list of this ItemConnector.  # noqa: E501
        :type: list[PropertyValue]
        """

        self._property_value_list = property_value_list

    @property
    def item(self):
        """Gets the item of this ItemConnector.  # noqa: E501


        :return: The item of this ItemConnector.  # noqa: E501
        :rtype: Item
        """
        return self._item

    @item.setter
    def item(self, item):
        """Sets the item of this ItemConnector.


        :param item: The item of this ItemConnector.  # noqa: E501
        :type: Item
        """

        self._item = item

    @property
    def connector(self):
        """Gets the connector of this ItemConnector.  # noqa: E501


        :return: The connector of this ItemConnector.  # noqa: E501
        :rtype: Connector
        """
        return self._connector

    @connector.setter
    def connector(self, connector):
        """Sets the connector of this ItemConnector.


        :param connector: The connector of this ItemConnector.  # noqa: E501
        :type: Connector
        """

        self._connector = connector

    @property
    def item_element_relationship_history_list(self):
        """Gets the item_element_relationship_history_list of this ItemConnector.  # noqa: E501


        :return: The item_element_relationship_history_list of this ItemConnector.  # noqa: E501
        :rtype: list[ItemElementRelationshipHistory]
        """
        return self._item_element_relationship_history_list

    @item_element_relationship_history_list.setter
    def item_element_relationship_history_list(self, item_element_relationship_history_list):
        """Sets the item_element_relationship_history_list of this ItemConnector.


        :param item_element_relationship_history_list: The item_element_relationship_history_list of this ItemConnector.  # noqa: E501
        :type: list[ItemElementRelationshipHistory]
        """

        self._item_element_relationship_history_list = item_element_relationship_history_list

    @property
    def item_element_relationship_history_list1(self):
        """Gets the item_element_relationship_history_list1 of this ItemConnector.  # noqa: E501


        :return: The item_element_relationship_history_list1 of this ItemConnector.  # noqa: E501
        :rtype: list[ItemElementRelationshipHistory]
        """
        return self._item_element_relationship_history_list1

    @item_element_relationship_history_list1.setter
    def item_element_relationship_history_list1(self, item_element_relationship_history_list1):
        """Sets the item_element_relationship_history_list1 of this ItemConnector.


        :param item_element_relationship_history_list1: The item_element_relationship_history_list1 of this ItemConnector.  # noqa: E501
        :type: list[ItemElementRelationshipHistory]
        """

        self._item_element_relationship_history_list1 = item_element_relationship_history_list1

    @property
    def item_resource_list(self):
        """Gets the item_resource_list of this ItemConnector.  # noqa: E501


        :return: The item_resource_list of this ItemConnector.  # noqa: E501
        :rtype: list[ItemResource]
        """
        return self._item_resource_list

    @item_resource_list.setter
    def item_resource_list(self, item_resource_list):
        """Sets the item_resource_list of this ItemConnector.


        :param item_resource_list: The item_resource_list of this ItemConnector.  # noqa: E501
        :type: list[ItemResource]
        """

        self._item_resource_list = item_resource_list

    @property
    def item_element_relationship_list(self):
        """Gets the item_element_relationship_list of this ItemConnector.  # noqa: E501


        :return: The item_element_relationship_list of this ItemConnector.  # noqa: E501
        :rtype: list[ItemElementRelationship]
        """
        return self._item_element_relationship_list

    @item_element_relationship_list.setter
    def item_element_relationship_list(self, item_element_relationship_list):
        """Sets the item_element_relationship_list of this ItemConnector.


        :param item_element_relationship_list: The item_element_relationship_list of this ItemConnector.  # noqa: E501
        :type: list[ItemElementRelationship]
        """

        self._item_element_relationship_list = item_element_relationship_list

    @property
    def item_element_relationship_list1(self):
        """Gets the item_element_relationship_list1 of this ItemConnector.  # noqa: E501


        :return: The item_element_relationship_list1 of this ItemConnector.  # noqa: E501
        :rtype: list[ItemElementRelationship]
        """
        return self._item_element_relationship_list1

    @item_element_relationship_list1.setter
    def item_element_relationship_list1(self, item_element_relationship_list1):
        """Sets the item_element_relationship_list1 of this ItemConnector.


        :param item_element_relationship_list1: The item_element_relationship_list1 of this ItemConnector.  # noqa: E501
        :type: list[ItemElementRelationship]
        """

        self._item_element_relationship_list1 = item_element_relationship_list1

    @property
    def item_connector_of_item_connected_to(self):
        """Gets the item_connector_of_item_connected_to of this ItemConnector.  # noqa: E501


        :return: The item_connector_of_item_connected_to of this ItemConnector.  # noqa: E501
        :rtype: ItemConnector
        """
        return self._item_connector_of_item_connected_to

    @item_connector_of_item_connected_to.setter
    def item_connector_of_item_connected_to(self, item_connector_of_item_connected_to):
        """Sets the item_connector_of_item_connected_to of this ItemConnector.


        :param item_connector_of_item_connected_to: The item_connector_of_item_connected_to of this ItemConnector.  # noqa: E501
        :type: ItemConnector
        """

        self._item_connector_of_item_connected_to = item_connector_of_item_connected_to

    @property
    def item_connected_via(self):
        """Gets the item_connected_via of this ItemConnector.  # noqa: E501


        :return: The item_connected_via of this ItemConnector.  # noqa: E501
        :rtype: Item
        """
        return self._item_connected_via

    @item_connected_via.setter
    def item_connected_via(self, item_connected_via):
        """Sets the item_connected_via of this ItemConnector.


        :param item_connected_via: The item_connected_via of this ItemConnector.  # noqa: E501
        :type: Item
        """

        self._item_connected_via = item_connected_via

    @property
    def connectors_to_update(self):
        """Gets the connectors_to_update of this ItemConnector.  # noqa: E501


        :return: The connectors_to_update of this ItemConnector.  # noqa: E501
        :rtype: list[Connector]
        """
        return self._connectors_to_update

    @connectors_to_update.setter
    def connectors_to_update(self, connectors_to_update):
        """Sets the connectors_to_update of this ItemConnector.


        :param connectors_to_update: The connectors_to_update of this ItemConnector.  # noqa: E501
        :type: list[Connector]
        """

        self._connectors_to_update = connectors_to_update

    @property
    def connectors_to_remove(self):
        """Gets the connectors_to_remove of this ItemConnector.  # noqa: E501


        :return: The connectors_to_remove of this ItemConnector.  # noqa: E501
        :rtype: list[Connector]
        """
        return self._connectors_to_remove

    @connectors_to_remove.setter
    def connectors_to_remove(self, connectors_to_remove):
        """Sets the connectors_to_remove of this ItemConnector.


        :param connectors_to_remove: The connectors_to_remove of this ItemConnector.  # noqa: E501
        :type: list[Connector]
        """

        self._connectors_to_remove = connectors_to_remove

    @property
    def connected(self):
        """Gets the connected of this ItemConnector.  # noqa: E501


        :return: The connected of this ItemConnector.  # noqa: E501
        :rtype: bool
        """
        return self._connected

    @connected.setter
    def connected(self, connected):
        """Sets the connected of this ItemConnector.


        :param connected: The connected of this ItemConnector.  # noqa: E501
        :type: bool
        """

        self._connected = connected

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemConnector):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemConnector):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class ItemElementRelationshipHistory(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'relationship_details': 'str',
        'label': 'str',
        'description': 'str',
        'entered_on_date_time': 'datetime',
        'item_element_relationship': 'ItemElementRelationship',
        'first_item_element': 'ItemElement',
        'first_item_connector': 'ItemConnector',
        'first_sort_order': 'float',
        'second_item_element': 'ItemElement',
        'second_item_connector': 'ItemConnector',
        'second_sort_order': 'float',
        'relationship_for_parent': 'ItemElementRelationship',
        'link_item_element': 'ItemElement',
        'resource_type': 'ResourceType',
        'entered_by_user': 'UserInfo'
    }

    attribute_map = {
        'id': 'id',
        'relationship_details': 'relationshipDetails',
        'label': 'label',
        'description': 'description',
        'entered_on_date_time': 'enteredOnDateTime',
        'item_element_relationship': 'itemElementRelationship',
        'first_item_element': 'firstItemElement',
        'first_item_connector': 'firstItemConnector',
        'first_sort_order': 'firstSortOrder',
        'second_item_element': 'secondItemElement',
        'second_item_connector': 'secondItemConnector',
        'second_sort_order': 'secondSortOrder',
        'relationship_for_parent': 'relationshipForParent',
        'link_item_element': 'linkItemElement',
        'resource_type': 'resourceType',
        'entered_by_user': 'enteredByUser'
    }

    def __init__(self, id=None, relationship_details=None, label=None, description=None, entered_on_date_time=None, item_element_relationship=None, first_item_element=None, first_item_connector=None, first_sort_order=None, second_item_element=None, second_item_connector=None, second_sort_order=None, relationship_for_parent=None, link_item_element=None, resource_type=None, entered_by_user=None, local_vars_configuration=None):  # noqa: E501
        """ItemElementRelationshipHistory - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._relationship_details = None
        self._label = None
        self._description = None
        self._entered_on_date_time = None
        self._item_element_relationship = None
        self._first_item_element = None
        self._first_item_connector = None
        self._first_sort_order = None
        self._second_item_element = None
        self._second_item_connector = None
        self._second_sort_order = None
        self._relationship_for_parent = None
        self._link_item_element = None
        self._resource_type = None
        self._entered_by_user = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if relationship_details is not None:
            self.relationship_details = relationship_details
        if label is not None:
            self.label = label
        if description is not None:
            self.description = description
        self.entered_on_date_time = entered_on_date_time
        if item_element_relationship is not None:
            self.item_element_relationship = item_element_relationship
        if first_item_element is not None:
            self.first_item_element = first_item_element
        if first_item_connector is not None:
            self.first_item_connector = first_item_connector
        if first_sort_order is not None:
            self.first_sort_order = first_sort_order
        if second_item_element is not None:
            self.second_item_element = second_item_element
        if second_item_connector is not None:
            self.second_item_connector = second_item_connector
        if second_sort_order is not None:
            self.second_sort_order = second_sort_order
        if relationship_for_parent is not None:
            self.relationship_for_parent = relationship_for_parent
        if link_item_element is not None:
            self.link_item_element = link_item_element
        if resource_type is not None:
            self.resource_type = resource_type
        if entered_by_user is not None:
            self.entered_by_user = entered_by_user

    @property
    def id(self):
        """Gets the id of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The id of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ItemElementRelationshipHistory.


        :param id: The id of this ItemElementRelationshipHistory.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def relationship_details(self):
        """Gets the relationship_details of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The relationship_details of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: str
        """
        return self._relationship_details

    @relationship_details.setter
    def relationship_details(self, relationship_details):
        """Sets the relationship_details of this ItemElementRelationshipHistory.


        :param relationship_details: The relationship_details of this ItemElementRelationshipHistory.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                relationship_details is not None and len(relationship_details) > 64):
            raise ValueError("Invalid value for `relationship_details`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                relationship_details is not None and len(relationship_details) < 0):
            raise ValueError("Invalid value for `relationship_details`, length must be greater than or equal to `0`")  # noqa: E501

        self._relationship_details = relationship_details

    @property
    def label(self):
        """Gets the label of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The label of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this ItemElementRelationshipHistory.


        :param label: The label of this ItemElementRelationshipHistory.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                label is not None and len(label) > 64):
            raise ValueError("Invalid value for `label`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                label is not None and len(label) < 0):
            raise ValueError("Invalid value for `label`, length must be greater than or equal to `0`")  # noqa: E501

        self._label = label

    @property
    def description(self):
        """Gets the description of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The description of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ItemElementRelationshipHistory.


        :param description: The description of this ItemElementRelationshipHistory.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 256):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def entered_on_date_time(self):
        """Gets the entered_on_date_time of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The entered_on_date_time of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: datetime
        """
        return self._entered_on_date_time

    @entered_on_date_time.setter
    def entered_on_date_time(self, entered_on_date_time):
        """Sets the entered_on_date_time of this ItemElementRelationshipHistory.


        :param entered_on_date_time: The entered_on_date_time of this ItemElementRelationshipHistory.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and entered_on_date_time is None:  # noqa: E501
            raise ValueError("Invalid value for `entered_on_date_time`, must not be `None`")  # noqa: E501

        self._entered_on_date_time = entered_on_date_time

    @property
    def item_element_relationship(self):
        """Gets the item_element_relationship of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The item_element_relationship of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: ItemElementRelationship
        """
        return self._item_element_relationship

    @item_element_relationship.setter
    def item_element_relationship(self, item_element_relationship):
        """Sets the item_element_relationship of this ItemElementRelationshipHistory.


        :param item_element_relationship: The item_element_relationship of this ItemElementRelationshipHistory.  # noqa: E501
        :type: ItemElementRelationship
        """

        self._item_element_relationship = item_element_relationship

    @property
    def first_item_element(self):
        """Gets the first_item_element of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The first_item_element of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: ItemElement
        """
        return self._first_item_element

    @first_item_element.setter
    def first_item_element(self, first_item_element):
        """Sets the first_item_element of this ItemElementRelationshipHistory.


        :param first_item_element: The first_item_element of this ItemElementRelationshipHistory.  # noqa: E501
        :type: ItemElement
        """

        self._first_item_element = first_item_element

    @property
    def first_item_connector(self):
        """Gets the first_item_connector of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The first_item_connector of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: ItemConnector
        """
        return self._first_item_connector

    @first_item_connector.setter
    def first_item_connector(self, first_item_connector):
        """Sets the first_item_connector of this ItemElementRelationshipHistory.


        :param first_item_connector: The first_item_connector of this ItemElementRelationshipHistory.  # noqa: E501
        :type: ItemConnector
        """

        self._first_item_connector = first_item_connector

    @property
    def first_sort_order(self):
        """Gets the first_sort_order of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The first_sort_order of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: float
        """
        return self._first_sort_order

    @first_sort_order.setter
    def first_sort_order(self, first_sort_order):
        """Sets the first_sort_order of this ItemElementRelationshipHistory.


        :param first_sort_order: The first_sort_order of this ItemElementRelationshipHistory.  # noqa: E501
        :type: float
        """

        self._first_sort_order = first_sort_order

    @property
    def second_item_element(self):
        """Gets the second_item_element of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The second_item_element of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: ItemElement
        """
        return self._second_item_element

    @second_item_element.setter
    def second_item_element(self, second_item_element):
        """Sets the second_item_element of this ItemElementRelationshipHistory.


        :param second_item_element: The second_item_element of this ItemElementRelationshipHistory.  # noqa: E501
        :type: ItemElement
        """

        self._second_item_element = second_item_element

    @property
    def second_item_connector(self):
        """Gets the second_item_connector of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The second_item_connector of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: ItemConnector
        """
        return self._second_item_connector

    @second_item_connector.setter
    def second_item_connector(self, second_item_connector):
        """Sets the second_item_connector of this ItemElementRelationshipHistory.


        :param second_item_connector: The second_item_connector of this ItemElementRelationshipHistory.  # noqa: E501
        :type: ItemConnector
        """

        self._second_item_connector = second_item_connector

    @property
    def second_sort_order(self):
        """Gets the second_sort_order of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The second_sort_order of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: float
        """
        return self._second_sort_order

    @second_sort_order.setter
    def second_sort_order(self, second_sort_order):
        """Sets the second_sort_order of this ItemElementRelationshipHistory.


        :param second_sort_order: The second_sort_order of this ItemElementRelationshipHistory.  # noqa: E501
        :type: float
        """

        self._second_sort_order = second_sort_order

    @property
    def relationship_for_parent(self):
        """Gets the relationship_for_parent of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The relationship_for_parent of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: ItemElementRelationship
        """
        return self._relationship_for_parent

    @relationship_for_parent.setter
    def relationship_for_parent(self, relationship_for_parent):
        """Sets the relationship_for_parent of this ItemElementRelationshipHistory.


        :param relationship_for_parent: The relationship_for_parent of this ItemElementRelationshipHistory.  # noqa: E501
        :type: ItemElementRelationship
        """

        self._relationship_for_parent = relationship_for_parent

    @property
    def link_item_element(self):
        """Gets the link_item_element of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The link_item_element of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: ItemElement
        """
        return self._link_item_element

    @link_item_element.setter
    def link_item_element(self, link_item_element):
        """Sets the link_item_element of this ItemElementRelationshipHistory.


        :param link_item_element: The link_item_element of this ItemElementRelationshipHistory.  # noqa: E501
        :type: ItemElement
        """

        self._link_item_element = link_item_element

    @property
    def resource_type(self):
        """Gets the resource_type of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The resource_type of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: ResourceType
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this ItemElementRelationshipHistory.


        :param resource_type: The resource_type of this ItemElementRelationshipHistory.  # noqa: E501
        :type: ResourceType
        """

        self._resource_type = resource_type

    @property
    def entered_by_user(self):
        """Gets the entered_by_user of this ItemElementRelationshipHistory.  # noqa: E501


        :return: The entered_by_user of this ItemElementRelationshipHistory.  # noqa: E501
        :rtype: UserInfo
        """
        return self._entered_by_user

    @entered_by_user.setter
    def entered_by_user(self, entered_by_user):
        """Sets the entered_by_user of this ItemElementRelationshipHistory.


        :param entered_by_user: The entered_by_user of this ItemElementRelationshipHistory.  # noqa: E501
        :type: UserInfo
        """

        self._entered_by_user = entered_by_user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemElementRelationshipHistory):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemElementRelationshipHistory):
            return True

        return self.to_dict() != other.to_dict()



#!/usr/bin/env python

# Copyright (c) UChicago Argonne, LLC. All rights reserved.
# See LICENSE file.
import base64
import os

from cdbApi import ApiException, DomainApi, FileUploadObject, LocationItemsApi, LogApi, PropertyValueApi, \
	ComponentCatalogItemsApi, ComponentInventoryItemsApi, ApiExceptionMessage, CableImportApi, AppItemsApi
from cdbApi.api.item_api import ItemApi
from cdbApi.api.downloads_api import DownloadsApi
from cdbApi.api.property_type_api import PropertyTypeApi
from cdbApi.api.search_api import SearchApi
from cdbApi.api.users_api import UsersApi
from cdbApi.api.sources_api import SourcesApi
from cdbApi.api.cable_catalog_items_api import CableCatalogItemsApi
from cdbApi.api.cable_design_items_api import CableDesignItemsApi
from cdbApi.api.machine_design_items_api import MachineDesignItemsApi
from cdbApi.api.connector_types_api import ConnectorTypesApi
from cdbApi.api_client import ApiClient
from cdbApi.api.authentication_api import AuthenticationApi
from cdbApi.configuration import Configuration


class CdbApiFactory:

	HEADER_TOKEN_KEY = "token"
	URL_FORMAT = "%s/views/item/view?id=%s"

	LOCATION_DOMAIN_ID = 1
	CATALOG_DOMAIN_ID = 2
	INVENTORY_DOMAIN_ID = 3
	MAARC_DOMAIN_ID= 5
	MACHINE_DESIGN_DOMAIN_ID = 6
	CABLE_CATALOG_DOMAIN_ID = 7
	CABLE_INVENTORY_DOMAIN_ID = 8
	CABLE_DESIGN_DOMAIN_ID = 9

	def __init__(self, cdbUrl):
		self.cdbUrl = cdbUrl
		self.config = Configuration(host=self.cdbUrl)
		self.apiClient = ApiClient(configuration=self.config)
		self.itemApi = ItemApi(api_client=self.apiClient)
		self.downloadsApi = DownloadsApi(api_client=self.apiClient)
		self.propertyTypeApi = PropertyTypeApi(api_client=self.apiClient)
		self.propertyValueApi = PropertyValueApi(api_client=self.apiClient)
		self.usersApi = UsersApi(api_client=self.apiClient)
		self.domainApi = DomainApi(api_client=self.apiClient)
		self.sourceApi = SourcesApi(api_client=self.apiClient)
		self.logApi = LogApi(api_client=self.apiClient)
		self.cableCatalogItemApi = CableCatalogItemsApi(api_client=self.apiClient)
		self.cableDesignItemApi = CableDesignItemsApi(api_client=self.apiClient)
		self.machineDesignItemApi = MachineDesignItemsApi(api_client=self.apiClient)
		self.appItemApi = AppItemsApi(api_client=self.apiClient)
		self.locationItemApi = LocationItemsApi(api_client=self.apiClient)
		self.componentCatalogItemApi = ComponentCatalogItemsApi(api_client=self.apiClient)
		self.componentInventoryItemApi = ComponentInventoryItemsApi(api_client=self.apiClient)
		self.connectorTypesApi = ConnectorTypesApi(api_client=self.apiClient)
		self.cableImportApi = CableImportApi(api_client=self.apiClient)
		self.searchApi = SearchApi(api_client=self.apiClient)

		self.authApi = AuthenticationApi(api_client=self.apiClient)

	def getItemApi(self) -> ItemApi:
		return self.itemApi

	def getDomainApi(self) -> DomainApi:
		return self.domainApi

	def getDownloadApi(self) -> DownloadsApi:
		return self.downloadsApi

	def getPropertyTypeApi(self) -> PropertyTypeApi:
		return self.propertyTypeApi

	def getPropertyValueApi(self) -> PropertyValueApi:
		return self.propertyValueApi

	def getUsersApi(self) -> UsersApi:
		return self.usersApi

	def getSourceApi(self) -> SourcesApi:
		return self.sourceApi

	def getLogApi(self) -> LogApi:
		return self.logApi

	def getCableCatalogItemApi(self) -> CableCatalogItemsApi:
		return self.cableCatalogItemApi

	def getCableDesignItemApi(self) -> CableDesignItemsApi:
		return self.cableDesignItemApi

	def getMachineDesignItemApi(self) -> MachineDesignItemsApi:
		return self.machineDesignItemApi
	
	def getAppItemApi(self) -> AppItemsApi:
		return self.appItemApi

	def getLocationItemApi(self) -> LocationItemsApi:
		return self.locationItemApi

	def getComponentCatalogItemApi(self) -> ComponentCatalogItemsApi:
		return self.componentCatalogItemApi

	def getConnectorTypesApi(self) -> ConnectorTypesApi:
		return self.connectorTypesApi

	def getCableImportApi(self) -> CableImportApi:
		return self.cableImportApi

	def getSearchApi(self) -> SearchApi:
		return self.searchApi

	def generateCDBUrlForItemId(self, itemId):
		return self.URL_FORMAT % (self.cdbUrl, str(itemId))

	def authenticateUser(self, username, password):
		response = self.authApi.authenticate_user_with_http_info(username=username, password=password)

		token = response[-1][self.HEADER_TOKEN_KEY]
		self.setAuthenticateToken(token)

	def setAuthenticateToken(self, token):
		self.apiClient.set_default_header(self.HEADER_TOKEN_KEY, token)

	def getAuthenticateToken(self):
		return self.apiClient.default_headers[self.HEADER_TOKEN_KEY]

	def testAuthenticated(self):
		self.authApi.verify_authenticated()

	def logOutUser(self):
		self.authApi.log_out()

	@classmethod
	def createFileUploadObject(cls, filePath):
		data = open(filePath, "rb").read()
		b64String = base64.b64encode(data).decode()

		fileName = os.path.basename(filePath)
		return FileUploadObject(file_name=fileName, base64_binary=b64String)

	def parseApiException(self, openApiException):
		responseType = ApiExceptionMessage.__name__
		openApiException.data = openApiException.body
		exObj = self.apiClient.deserialize(openApiException, responseType)
		exObj.status = openApiException.status
		return exObj

def run_command():
	# Example
	print("\nEnter cdb URL (ex: https://cdb.aps.anl.gov/cdb): ")
	hostname = input()
        
	apiFactory = CdbApiFactory(hostname)
	itemApi = apiFactory.getItemApi()

	catalogItems = itemApi.get_catalog_items()
	catalogItem = catalogItems[0]

	# Lists of items seem to be lists of dict items
	catalogId = catalogItem.id

	# Single items seem to be appropriate type
	catalogFetchedById = itemApi.get_item_by_id(catalogId)
	print(catalogFetchedById.name)

	inventoryItemPerCatalog = itemApi.get_items_derived_from_item_by_item_id(catalogId)
	print(inventoryItemPerCatalog)

	print("\n\n\nWould you like to test authentication? (y/N): ")
	resp = input()
	if resp == 'y' or resp == "Y":
		import getpass
		print("Username: ")
		username = input()
		print("Password: ")
		password = getpass.getpass()

		try:
			apiFactory.authenticateUser(username, password)
			apiFactory.testAuthenticated()
			apiFactory.logOutUser()
		except ApiException:
			print("Authentication failed!")
			exit(1)

		print("Success!")

if __name__ == '__main__':
	run_command()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class ItemElementHistory(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'item_element': 'ItemElement',
        'snapshot_element_name': 'str',
        'is_required': 'bool',
        'is_housed': 'bool',
        'description': 'str',
        'sort_order': 'float',
        'derived_from_item_element': 'ItemElement',
        'represents_item_element': 'ItemElement',
        'parent_item': 'Item',
        'snapshot_parent_name': 'str',
        'contained_item2': 'Item',
        'snapshot_contained_item2_name': 'str',
        'entered_by_user': 'UserInfo',
        'entered_on_date_time': 'datetime',
        'snapshot_contained_item_name': 'str',
        'contained_item': 'Item'
    }

    attribute_map = {
        'id': 'id',
        'item_element': 'itemElement',
        'snapshot_element_name': 'snapshotElementName',
        'is_required': 'isRequired',
        'is_housed': 'isHoused',
        'description': 'description',
        'sort_order': 'sortOrder',
        'derived_from_item_element': 'derivedFromItemElement',
        'represents_item_element': 'representsItemElement',
        'parent_item': 'parentItem',
        'snapshot_parent_name': 'snapshotParentName',
        'contained_item2': 'containedItem2',
        'snapshot_contained_item2_name': 'snapshotContainedItem2Name',
        'entered_by_user': 'enteredByUser',
        'entered_on_date_time': 'enteredOnDateTime',
        'snapshot_contained_item_name': 'snapshotContainedItemName',
        'contained_item': 'containedItem'
    }

    def __init__(self, id=None, item_element=None, snapshot_element_name=None, is_required=None, is_housed=None, description=None, sort_order=None, derived_from_item_element=None, represents_item_element=None, parent_item=None, snapshot_parent_name=None, contained_item2=None, snapshot_contained_item2_name=None, entered_by_user=None, entered_on_date_time=None, snapshot_contained_item_name=None, contained_item=None, local_vars_configuration=None):  # noqa: E501
        """ItemElementHistory - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._item_element = None
        self._snapshot_element_name = None
        self._is_required = None
        self._is_housed = None
        self._description = None
        self._sort_order = None
        self._derived_from_item_element = None
        self._represents_item_element = None
        self._parent_item = None
        self._snapshot_parent_name = None
        self._contained_item2 = None
        self._snapshot_contained_item2_name = None
        self._entered_by_user = None
        self._entered_on_date_time = None
        self._snapshot_contained_item_name = None
        self._contained_item = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if item_element is not None:
            self.item_element = item_element
        if snapshot_element_name is not None:
            self.snapshot_element_name = snapshot_element_name
        if is_required is not None:
            self.is_required = is_required
        if is_housed is not None:
            self.is_housed = is_housed
        if description is not None:
            self.description = description
        if sort_order is not None:
            self.sort_order = sort_order
        if derived_from_item_element is not None:
            self.derived_from_item_element = derived_from_item_element
        if represents_item_element is not None:
            self.represents_item_element = represents_item_element
        if parent_item is not None:
            self.parent_item = parent_item
        if snapshot_parent_name is not None:
            self.snapshot_parent_name = snapshot_parent_name
        if contained_item2 is not None:
            self.contained_item2 = contained_item2
        if snapshot_contained_item2_name is not None:
            self.snapshot_contained_item2_name = snapshot_contained_item2_name
        if entered_by_user is not None:
            self.entered_by_user = entered_by_user
        if entered_on_date_time is not None:
            self.entered_on_date_time = entered_on_date_time
        if snapshot_contained_item_name is not None:
            self.snapshot_contained_item_name = snapshot_contained_item_name
        if contained_item is not None:
            self.contained_item = contained_item

    @property
    def id(self):
        """Gets the id of this ItemElementHistory.  # noqa: E501


        :return: The id of this ItemElementHistory.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ItemElementHistory.


        :param id: The id of this ItemElementHistory.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def item_element(self):
        """Gets the item_element of this ItemElementHistory.  # noqa: E501


        :return: The item_element of this ItemElementHistory.  # noqa: E501
        :rtype: ItemElement
        """
        return self._item_element

    @item_element.setter
    def item_element(self, item_element):
        """Sets the item_element of this ItemElementHistory.


        :param item_element: The item_element of this ItemElementHistory.  # noqa: E501
        :type: ItemElement
        """

        self._item_element = item_element

    @property
    def snapshot_element_name(self):
        """Gets the snapshot_element_name of this ItemElementHistory.  # noqa: E501


        :return: The snapshot_element_name of this ItemElementHistory.  # noqa: E501
        :rtype: str
        """
        return self._snapshot_element_name

    @snapshot_element_name.setter
    def snapshot_element_name(self, snapshot_element_name):
        """Sets the snapshot_element_name of this ItemElementHistory.


        :param snapshot_element_name: The snapshot_element_name of this ItemElementHistory.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                snapshot_element_name is not None and len(snapshot_element_name) > 64):
            raise ValueError("Invalid value for `snapshot_element_name`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                snapshot_element_name is not None and len(snapshot_element_name) < 0):
            raise ValueError("Invalid value for `snapshot_element_name`, length must be greater than or equal to `0`")  # noqa: E501

        self._snapshot_element_name = snapshot_element_name

    @property
    def is_required(self):
        """Gets the is_required of this ItemElementHistory.  # noqa: E501


        :return: The is_required of this ItemElementHistory.  # noqa: E501
        :rtype: bool
        """
        return self._is_required

    @is_required.setter
    def is_required(self, is_required):
        """Sets the is_required of this ItemElementHistory.


        :param is_required: The is_required of this ItemElementHistory.  # noqa: E501
        :type: bool
        """

        self._is_required = is_required

    @property
    def is_housed(self):
        """Gets the is_housed of this ItemElementHistory.  # noqa: E501


        :return: The is_housed of this ItemElementHistory.  # noqa: E501
        :rtype: bool
        """
        return self._is_housed

    @is_housed.setter
    def is_housed(self, is_housed):
        """Sets the is_housed of this ItemElementHistory.


        :param is_housed: The is_housed of this ItemElementHistory.  # noqa: E501
        :type: bool
        """

        self._is_housed = is_housed

    @property
    def description(self):
        """Gets the description of this ItemElementHistory.  # noqa: E501


        :return: The description of this ItemElementHistory.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ItemElementHistory.


        :param description: The description of this ItemElementHistory.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 256):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def sort_order(self):
        """Gets the sort_order of this ItemElementHistory.  # noqa: E501


        :return: The sort_order of this ItemElementHistory.  # noqa: E501
        :rtype: float
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this ItemElementHistory.


        :param sort_order: The sort_order of this ItemElementHistory.  # noqa: E501
        :type: float
        """

        self._sort_order = sort_order

    @property
    def derived_from_item_element(self):
        """Gets the derived_from_item_element of this ItemElementHistory.  # noqa: E501


        :return: The derived_from_item_element of this ItemElementHistory.  # noqa: E501
        :rtype: ItemElement
        """
        return self._derived_from_item_element

    @derived_from_item_element.setter
    def derived_from_item_element(self, derived_from_item_element):
        """Sets the derived_from_item_element of this ItemElementHistory.


        :param derived_from_item_element: The derived_from_item_element of this ItemElementHistory.  # noqa: E501
        :type: ItemElement
        """

        self._derived_from_item_element = derived_from_item_element

    @property
    def represents_item_element(self):
        """Gets the represents_item_element of this ItemElementHistory.  # noqa: E501


        :return: The represents_item_element of this ItemElementHistory.  # noqa: E501
        :rtype: ItemElement
        """
        return self._represents_item_element

    @represents_item_element.setter
    def represents_item_element(self, represents_item_element):
        """Sets the represents_item_element of this ItemElementHistory.


        :param represents_item_element: The represents_item_element of this ItemElementHistory.  # noqa: E501
        :type: ItemElement
        """

        self._represents_item_element = represents_item_element

    @property
    def parent_item(self):
        """Gets the parent_item of this ItemElementHistory.  # noqa: E501


        :return: The parent_item of this ItemElementHistory.  # noqa: E501
        :rtype: Item
        """
        return self._parent_item

    @parent_item.setter
    def parent_item(self, parent_item):
        """Sets the parent_item of this ItemElementHistory.


        :param parent_item: The parent_item of this ItemElementHistory.  # noqa: E501
        :type: Item
        """

        self._parent_item = parent_item

    @property
    def snapshot_parent_name(self):
        """Gets the snapshot_parent_name of this ItemElementHistory.  # noqa: E501


        :return: The snapshot_parent_name of this ItemElementHistory.  # noqa: E501
        :rtype: str
        """
        return self._snapshot_parent_name

    @snapshot_parent_name.setter
    def snapshot_parent_name(self, snapshot_parent_name):
        """Sets the snapshot_parent_name of this ItemElementHistory.


        :param snapshot_parent_name: The snapshot_parent_name of this ItemElementHistory.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                snapshot_parent_name is not None and len(snapshot_parent_name) > 256):
            raise ValueError("Invalid value for `snapshot_parent_name`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                snapshot_parent_name is not None and len(snapshot_parent_name) < 0):
            raise ValueError("Invalid value for `snapshot_parent_name`, length must be greater than or equal to `0`")  # noqa: E501

        self._snapshot_parent_name = snapshot_parent_name

    @property
    def contained_item2(self):
        """Gets the contained_item2 of this ItemElementHistory.  # noqa: E501


        :return: The contained_item2 of this ItemElementHistory.  # noqa: E501
        :rtype: Item
        """
        return self._contained_item2

    @contained_item2.setter
    def contained_item2(self, contained_item2):
        """Sets the contained_item2 of this ItemElementHistory.


        :param contained_item2: The contained_item2 of this ItemElementHistory.  # noqa: E501
        :type: Item
        """

        self._contained_item2 = contained_item2

    @property
    def snapshot_contained_item2_name(self):
        """Gets the snapshot_contained_item2_name of this ItemElementHistory.  # noqa: E501


        :return: The snapshot_contained_item2_name of this ItemElementHistory.  # noqa: E501
        :rtype: str
        """
        return self._snapshot_contained_item2_name

    @snapshot_contained_item2_name.setter
    def snapshot_contained_item2_name(self, snapshot_contained_item2_name):
        """Sets the snapshot_contained_item2_name of this ItemElementHistory.


        :param snapshot_contained_item2_name: The snapshot_contained_item2_name of this ItemElementHistory.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                snapshot_contained_item2_name is not None and len(snapshot_contained_item2_name) > 256):
            raise ValueError("Invalid value for `snapshot_contained_item2_name`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                snapshot_contained_item2_name is not None and len(snapshot_contained_item2_name) < 0):
            raise ValueError("Invalid value for `snapshot_contained_item2_name`, length must be greater than or equal to `0`")  # noqa: E501

        self._snapshot_contained_item2_name = snapshot_contained_item2_name

    @property
    def entered_by_user(self):
        """Gets the entered_by_user of this ItemElementHistory.  # noqa: E501


        :return: The entered_by_user of this ItemElementHistory.  # noqa: E501
        :rtype: UserInfo
        """
        return self._entered_by_user

    @entered_by_user.setter
    def entered_by_user(self, entered_by_user):
        """Sets the entered_by_user of this ItemElementHistory.


        :param entered_by_user: The entered_by_user of this ItemElementHistory.  # noqa: E501
        :type: UserInfo
        """

        self._entered_by_user = entered_by_user

    @property
    def entered_on_date_time(self):
        """Gets the entered_on_date_time of this ItemElementHistory.  # noqa: E501


        :return: The entered_on_date_time of this ItemElementHistory.  # noqa: E501
        :rtype: datetime
        """
        return self._entered_on_date_time

    @entered_on_date_time.setter
    def entered_on_date_time(self, entered_on_date_time):
        """Sets the entered_on_date_time of this ItemElementHistory.


        :param entered_on_date_time: The entered_on_date_time of this ItemElementHistory.  # noqa: E501
        :type: datetime
        """

        self._entered_on_date_time = entered_on_date_time

    @property
    def snapshot_contained_item_name(self):
        """Gets the snapshot_contained_item_name of this ItemElementHistory.  # noqa: E501


        :return: The snapshot_contained_item_name of this ItemElementHistory.  # noqa: E501
        :rtype: str
        """
        return self._snapshot_contained_item_name

    @snapshot_contained_item_name.setter
    def snapshot_contained_item_name(self, snapshot_contained_item_name):
        """Sets the snapshot_contained_item_name of this ItemElementHistory.


        :param snapshot_contained_item_name: The snapshot_contained_item_name of this ItemElementHistory.  # noqa: E501
        :type: str
        """

        self._snapshot_contained_item_name = snapshot_contained_item_name

    @property
    def contained_item(self):
        """Gets the contained_item of this ItemElementHistory.  # noqa: E501


        :return: The contained_item of this ItemElementHistory.  # noqa: E501
        :rtype: Item
        """
        return self._contained_item

    @contained_item.setter
    def contained_item(self, contained_item):
        """Sets the contained_item of this ItemElementHistory.


        :param contained_item: The contained_item of this ItemElementHistory.  # noqa: E501
        :type: Item
        """

        self._contained_item = contained_item

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemElementHistory):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemElementHistory):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class Item(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'item_identifier1': 'str',
        'item_identifier2': 'str',
        'qr_id': 'int',
        'domain': 'Domain',
        'derived_from_item': 'Item',
        'domain_id': 'int',
        'item_category_list_import': 'list[ItemCategory]',
        'primary_image_for_item': 'str',
        'item_control': 'bool',
        'max_sort_order': 'float',
        'description': 'str',
        'entity_type_list': 'list[EntityType]',
        'item_category_list': 'list[ItemCategory]',
        'item_type_list': 'list[ItemType]',
        'item_project_list': 'list[ItemProject]',
        'item_source_list': 'list[ItemSource]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'item_identifier1': 'itemIdentifier1',
        'item_identifier2': 'itemIdentifier2',
        'qr_id': 'qrId',
        'domain': 'domain',
        'derived_from_item': 'derivedFromItem',
        'domain_id': 'domainId',
        'item_category_list_import': 'itemCategoryListImport',
        'primary_image_for_item': 'primaryImageForItem',
        'item_control': 'itemControl',
        'max_sort_order': 'maxSortOrder',
        'description': 'description',
        'entity_type_list': 'entityTypeList',
        'item_category_list': 'itemCategoryList',
        'item_type_list': 'itemTypeList',
        'item_project_list': 'itemProjectList',
        'item_source_list': 'itemSourceList'
    }

    def __init__(self, id=None, name=None, item_identifier1=None, item_identifier2=None, qr_id=None, domain=None, derived_from_item=None, domain_id=None, item_category_list_import=None, primary_image_for_item=None, item_control=None, max_sort_order=None, description=None, entity_type_list=None, item_category_list=None, item_type_list=None, item_project_list=None, item_source_list=None, local_vars_configuration=None):  # noqa: E501
        """Item - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._item_identifier1 = None
        self._item_identifier2 = None
        self._qr_id = None
        self._domain = None
        self._derived_from_item = None
        self._domain_id = None
        self._item_category_list_import = None
        self._primary_image_for_item = None
        self._item_control = None
        self._max_sort_order = None
        self._description = None
        self._entity_type_list = None
        self._item_category_list = None
        self._item_type_list = None
        self._item_project_list = None
        self._item_source_list = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if item_identifier1 is not None:
            self.item_identifier1 = item_identifier1
        if item_identifier2 is not None:
            self.item_identifier2 = item_identifier2
        if qr_id is not None:
            self.qr_id = qr_id
        if domain is not None:
            self.domain = domain
        if derived_from_item is not None:
            self.derived_from_item = derived_from_item
        if domain_id is not None:
            self.domain_id = domain_id
        if item_category_list_import is not None:
            self.item_category_list_import = item_category_list_import
        if primary_image_for_item is not None:
            self.primary_image_for_item = primary_image_for_item
        if item_control is not None:
            self.item_control = item_control
        if max_sort_order is not None:
            self.max_sort_order = max_sort_order
        if description is not None:
            self.description = description
        if entity_type_list is not None:
            self.entity_type_list = entity_type_list
        if item_category_list is not None:
            self.item_category_list = item_category_list
        if item_type_list is not None:
            self.item_type_list = item_type_list
        if item_project_list is not None:
            self.item_project_list = item_project_list
        if item_source_list is not None:
            self.item_source_list = item_source_list

    @property
    def id(self):
        """Gets the id of this Item.  # noqa: E501


        :return: The id of this Item.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Item.


        :param id: The id of this Item.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Item.  # noqa: E501


        :return: The name of this Item.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Item.


        :param name: The name of this Item.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 128):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 0):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `0`")  # noqa: E501

        self._name = name

    @property
    def item_identifier1(self):
        """Gets the item_identifier1 of this Item.  # noqa: E501


        :return: The item_identifier1 of this Item.  # noqa: E501
        :rtype: str
        """
        return self._item_identifier1

    @item_identifier1.setter
    def item_identifier1(self, item_identifier1):
        """Sets the item_identifier1 of this Item.


        :param item_identifier1: The item_identifier1 of this Item.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                item_identifier1 is not None and len(item_identifier1) > 128):
            raise ValueError("Invalid value for `item_identifier1`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                item_identifier1 is not None and len(item_identifier1) < 0):
            raise ValueError("Invalid value for `item_identifier1`, length must be greater than or equal to `0`")  # noqa: E501

        self._item_identifier1 = item_identifier1

    @property
    def item_identifier2(self):
        """Gets the item_identifier2 of this Item.  # noqa: E501


        :return: The item_identifier2 of this Item.  # noqa: E501
        :rtype: str
        """
        return self._item_identifier2

    @item_identifier2.setter
    def item_identifier2(self, item_identifier2):
        """Sets the item_identifier2 of this Item.


        :param item_identifier2: The item_identifier2 of this Item.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                item_identifier2 is not None and len(item_identifier2) > 128):
            raise ValueError("Invalid value for `item_identifier2`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                item_identifier2 is not None and len(item_identifier2) < 0):
            raise ValueError("Invalid value for `item_identifier2`, length must be greater than or equal to `0`")  # noqa: E501

        self._item_identifier2 = item_identifier2

    @property
    def qr_id(self):
        """Gets the qr_id of this Item.  # noqa: E501


        :return: The qr_id of this Item.  # noqa: E501
        :rtype: int
        """
        return self._qr_id

    @qr_id.setter
    def qr_id(self, qr_id):
        """Sets the qr_id of this Item.


        :param qr_id: The qr_id of this Item.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                qr_id is not None and qr_id < 0):  # noqa: E501
            raise ValueError("Invalid value for `qr_id`, must be a value greater than or equal to `0`")  # noqa: E501

        self._qr_id = qr_id

    @property
    def domain(self):
        """Gets the domain of this Item.  # noqa: E501


        :return: The domain of this Item.  # noqa: E501
        :rtype: Domain
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this Item.


        :param domain: The domain of this Item.  # noqa: E501
        :type: Domain
        """

        self._domain = domain

    @property
    def derived_from_item(self):
        """Gets the derived_from_item of this Item.  # noqa: E501


        :return: The derived_from_item of this Item.  # noqa: E501
        :rtype: Item
        """
        return self._derived_from_item

    @derived_from_item.setter
    def derived_from_item(self, derived_from_item):
        """Sets the derived_from_item of this Item.


        :param derived_from_item: The derived_from_item of this Item.  # noqa: E501
        :type: Item
        """

        self._derived_from_item = derived_from_item

    @property
    def domain_id(self):
        """Gets the domain_id of this Item.  # noqa: E501


        :return: The domain_id of this Item.  # noqa: E501
        :rtype: int
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this Item.


        :param domain_id: The domain_id of this Item.  # noqa: E501
        :type: int
        """

        self._domain_id = domain_id

    @property
    def item_category_list_import(self):
        """Gets the item_category_list_import of this Item.  # noqa: E501


        :return: The item_category_list_import of this Item.  # noqa: E501
        :rtype: list[ItemCategory]
        """
        return self._item_category_list_import

    @item_category_list_import.setter
    def item_category_list_import(self, item_category_list_import):
        """Sets the item_category_list_import of this Item.


        :param item_category_list_import: The item_category_list_import of this Item.  # noqa: E501
        :type: list[ItemCategory]
        """

        self._item_category_list_import = item_category_list_import

    @property
    def primary_image_for_item(self):
        """Gets the primary_image_for_item of this Item.  # noqa: E501


        :return: The primary_image_for_item of this Item.  # noqa: E501
        :rtype: str
        """
        return self._primary_image_for_item

    @primary_image_for_item.setter
    def primary_image_for_item(self, primary_image_for_item):
        """Sets the primary_image_for_item of this Item.


        :param primary_image_for_item: The primary_image_for_item of this Item.  # noqa: E501
        :type: str
        """

        self._primary_image_for_item = primary_image_for_item

    @property
    def item_control(self):
        """Gets the item_control of this Item.  # noqa: E501


        :return: The item_control of this Item.  # noqa: E501
        :rtype: bool
        """
        return self._item_control

    @item_control.setter
    def item_control(self, item_control):
        """Sets the item_control of this Item.


        :param item_control: The item_control of this Item.  # noqa: E501
        :type: bool
        """

        self._item_control = item_control

    @property
    def max_sort_order(self):
        """Gets the max_sort_order of this Item.  # noqa: E501


        :return: The max_sort_order of this Item.  # noqa: E501
        :rtype: float
        """
        return self._max_sort_order

    @max_sort_order.setter
    def max_sort_order(self, max_sort_order):
        """Sets the max_sort_order of this Item.


        :param max_sort_order: The max_sort_order of this Item.  # noqa: E501
        :type: float
        """

        self._max_sort_order = max_sort_order

    @property
    def description(self):
        """Gets the description of this Item.  # noqa: E501


        :return: The description of this Item.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Item.


        :param description: The description of this Item.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 256):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def entity_type_list(self):
        """Gets the entity_type_list of this Item.  # noqa: E501


        :return: The entity_type_list of this Item.  # noqa: E501
        :rtype: list[EntityType]
        """
        return self._entity_type_list

    @entity_type_list.setter
    def entity_type_list(self, entity_type_list):
        """Sets the entity_type_list of this Item.


        :param entity_type_list: The entity_type_list of this Item.  # noqa: E501
        :type: list[EntityType]
        """

        self._entity_type_list = entity_type_list

    @property
    def item_category_list(self):
        """Gets the item_category_list of this Item.  # noqa: E501


        :return: The item_category_list of this Item.  # noqa: E501
        :rtype: list[ItemCategory]
        """
        return self._item_category_list

    @item_category_list.setter
    def item_category_list(self, item_category_list):
        """Sets the item_category_list of this Item.


        :param item_category_list: The item_category_list of this Item.  # noqa: E501
        :type: list[ItemCategory]
        """

        self._item_category_list = item_category_list

    @property
    def item_type_list(self):
        """Gets the item_type_list of this Item.  # noqa: E501


        :return: The item_type_list of this Item.  # noqa: E501
        :rtype: list[ItemType]
        """
        return self._item_type_list

    @item_type_list.setter
    def item_type_list(self, item_type_list):
        """Sets the item_type_list of this Item.


        :param item_type_list: The item_type_list of this Item.  # noqa: E501
        :type: list[ItemType]
        """

        self._item_type_list = item_type_list

    @property
    def item_project_list(self):
        """Gets the item_project_list of this Item.  # noqa: E501


        :return: The item_project_list of this Item.  # noqa: E501
        :rtype: list[ItemProject]
        """
        return self._item_project_list

    @item_project_list.setter
    def item_project_list(self, item_project_list):
        """Sets the item_project_list of this Item.


        :param item_project_list: The item_project_list of this Item.  # noqa: E501
        :type: list[ItemProject]
        """

        self._item_project_list = item_project_list

    @property
    def item_source_list(self):
        """Gets the item_source_list of this Item.  # noqa: E501


        :return: The item_source_list of this Item.  # noqa: E501
        :rtype: list[ItemSource]
        """
        return self._item_source_list

    @item_source_list.setter
    def item_source_list(self, item_source_list):
        """Sets the item_source_list of this Item.


        :param item_source_list: The item_source_list of this Item.  # noqa: E501
        :type: list[ItemSource]
        """

        self._item_source_list = item_source_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Item):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Item):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class SearchEntitiesOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'search_text': 'str',
        'include_catalog': 'bool',
        'include_inventory': 'bool',
        'include_cable_catalog': 'bool',
        'include_cable_inventory': 'bool',
        'include_cable_design': 'bool',
        'include_machine_design': 'bool',
        'include_item_location': 'bool',
        'include_maarc': 'bool',
        'include_item_element': 'bool',
        'include_item_type': 'bool',
        'include_item_categoy': 'bool',
        'include_property_type': 'bool',
        'include_property_type_category': 'bool',
        'include_source': 'bool',
        'include_user': 'bool',
        'include_user_group': 'bool'
    }

    attribute_map = {
        'search_text': 'searchText',
        'include_catalog': 'includeCatalog',
        'include_inventory': 'includeInventory',
        'include_cable_catalog': 'includeCableCatalog',
        'include_cable_inventory': 'includeCableInventory',
        'include_cable_design': 'includeCableDesign',
        'include_machine_design': 'includeMachineDesign',
        'include_item_location': 'includeItemLocation',
        'include_maarc': 'includeMAARC',
        'include_item_element': 'includeItemElement',
        'include_item_type': 'includeItemType',
        'include_item_categoy': 'includeItemCategoy',
        'include_property_type': 'includePropertyType',
        'include_property_type_category': 'includePropertyTypeCategory',
        'include_source': 'includeSource',
        'include_user': 'includeUser',
        'include_user_group': 'includeUserGroup'
    }

    def __init__(self, search_text=None, include_catalog=None, include_inventory=None, include_cable_catalog=None, include_cable_inventory=None, include_cable_design=None, include_machine_design=None, include_item_location=None, include_maarc=None, include_item_element=None, include_item_type=None, include_item_categoy=None, include_property_type=None, include_property_type_category=None, include_source=None, include_user=None, include_user_group=None, local_vars_configuration=None):  # noqa: E501
        """SearchEntitiesOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._search_text = None
        self._include_catalog = None
        self._include_inventory = None
        self._include_cable_catalog = None
        self._include_cable_inventory = None
        self._include_cable_design = None
        self._include_machine_design = None
        self._include_item_location = None
        self._include_maarc = None
        self._include_item_element = None
        self._include_item_type = None
        self._include_item_categoy = None
        self._include_property_type = None
        self._include_property_type_category = None
        self._include_source = None
        self._include_user = None
        self._include_user_group = None
        self.discriminator = None

        if search_text is not None:
            self.search_text = search_text
        if include_catalog is not None:
            self.include_catalog = include_catalog
        if include_inventory is not None:
            self.include_inventory = include_inventory
        if include_cable_catalog is not None:
            self.include_cable_catalog = include_cable_catalog
        if include_cable_inventory is not None:
            self.include_cable_inventory = include_cable_inventory
        if include_cable_design is not None:
            self.include_cable_design = include_cable_design
        if include_machine_design is not None:
            self.include_machine_design = include_machine_design
        if include_item_location is not None:
            self.include_item_location = include_item_location
        if include_maarc is not None:
            self.include_maarc = include_maarc
        if include_item_element is not None:
            self.include_item_element = include_item_element
        if include_item_type is not None:
            self.include_item_type = include_item_type
        if include_item_categoy is not None:
            self.include_item_categoy = include_item_categoy
        if include_property_type is not None:
            self.include_property_type = include_property_type
        if include_property_type_category is not None:
            self.include_property_type_category = include_property_type_category
        if include_source is not None:
            self.include_source = include_source
        if include_user is not None:
            self.include_user = include_user
        if include_user_group is not None:
            self.include_user_group = include_user_group

    @property
    def search_text(self):
        """Gets the search_text of this SearchEntitiesOptions.  # noqa: E501


        :return: The search_text of this SearchEntitiesOptions.  # noqa: E501
        :rtype: str
        """
        return self._search_text

    @search_text.setter
    def search_text(self, search_text):
        """Sets the search_text of this SearchEntitiesOptions.


        :param search_text: The search_text of this SearchEntitiesOptions.  # noqa: E501
        :type: str
        """

        self._search_text = search_text

    @property
    def include_catalog(self):
        """Gets the include_catalog of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_catalog of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_catalog

    @include_catalog.setter
    def include_catalog(self, include_catalog):
        """Sets the include_catalog of this SearchEntitiesOptions.


        :param include_catalog: The include_catalog of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_catalog = include_catalog

    @property
    def include_inventory(self):
        """Gets the include_inventory of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_inventory of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_inventory

    @include_inventory.setter
    def include_inventory(self, include_inventory):
        """Sets the include_inventory of this SearchEntitiesOptions.


        :param include_inventory: The include_inventory of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_inventory = include_inventory

    @property
    def include_cable_catalog(self):
        """Gets the include_cable_catalog of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_cable_catalog of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_cable_catalog

    @include_cable_catalog.setter
    def include_cable_catalog(self, include_cable_catalog):
        """Sets the include_cable_catalog of this SearchEntitiesOptions.


        :param include_cable_catalog: The include_cable_catalog of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_cable_catalog = include_cable_catalog

    @property
    def include_cable_inventory(self):
        """Gets the include_cable_inventory of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_cable_inventory of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_cable_inventory

    @include_cable_inventory.setter
    def include_cable_inventory(self, include_cable_inventory):
        """Sets the include_cable_inventory of this SearchEntitiesOptions.


        :param include_cable_inventory: The include_cable_inventory of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_cable_inventory = include_cable_inventory

    @property
    def include_cable_design(self):
        """Gets the include_cable_design of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_cable_design of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_cable_design

    @include_cable_design.setter
    def include_cable_design(self, include_cable_design):
        """Sets the include_cable_design of this SearchEntitiesOptions.


        :param include_cable_design: The include_cable_design of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_cable_design = include_cable_design

    @property
    def include_machine_design(self):
        """Gets the include_machine_design of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_machine_design of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_machine_design

    @include_machine_design.setter
    def include_machine_design(self, include_machine_design):
        """Sets the include_machine_design of this SearchEntitiesOptions.


        :param include_machine_design: The include_machine_design of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_machine_design = include_machine_design

    @property
    def include_item_location(self):
        """Gets the include_item_location of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_item_location of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_item_location

    @include_item_location.setter
    def include_item_location(self, include_item_location):
        """Sets the include_item_location of this SearchEntitiesOptions.


        :param include_item_location: The include_item_location of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_item_location = include_item_location

    @property
    def include_maarc(self):
        """Gets the include_maarc of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_maarc of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_maarc

    @include_maarc.setter
    def include_maarc(self, include_maarc):
        """Sets the include_maarc of this SearchEntitiesOptions.


        :param include_maarc: The include_maarc of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_maarc = include_maarc

    @property
    def include_item_element(self):
        """Gets the include_item_element of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_item_element of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_item_element

    @include_item_element.setter
    def include_item_element(self, include_item_element):
        """Sets the include_item_element of this SearchEntitiesOptions.


        :param include_item_element: The include_item_element of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_item_element = include_item_element

    @property
    def include_item_type(self):
        """Gets the include_item_type of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_item_type of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_item_type

    @include_item_type.setter
    def include_item_type(self, include_item_type):
        """Sets the include_item_type of this SearchEntitiesOptions.


        :param include_item_type: The include_item_type of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_item_type = include_item_type

    @property
    def include_item_categoy(self):
        """Gets the include_item_categoy of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_item_categoy of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_item_categoy

    @include_item_categoy.setter
    def include_item_categoy(self, include_item_categoy):
        """Sets the include_item_categoy of this SearchEntitiesOptions.


        :param include_item_categoy: The include_item_categoy of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_item_categoy = include_item_categoy

    @property
    def include_property_type(self):
        """Gets the include_property_type of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_property_type of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_property_type

    @include_property_type.setter
    def include_property_type(self, include_property_type):
        """Sets the include_property_type of this SearchEntitiesOptions.


        :param include_property_type: The include_property_type of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_property_type = include_property_type

    @property
    def include_property_type_category(self):
        """Gets the include_property_type_category of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_property_type_category of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_property_type_category

    @include_property_type_category.setter
    def include_property_type_category(self, include_property_type_category):
        """Sets the include_property_type_category of this SearchEntitiesOptions.


        :param include_property_type_category: The include_property_type_category of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_property_type_category = include_property_type_category

    @property
    def include_source(self):
        """Gets the include_source of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_source of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_source

    @include_source.setter
    def include_source(self, include_source):
        """Sets the include_source of this SearchEntitiesOptions.


        :param include_source: The include_source of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_source = include_source

    @property
    def include_user(self):
        """Gets the include_user of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_user of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_user

    @include_user.setter
    def include_user(self, include_user):
        """Sets the include_user of this SearchEntitiesOptions.


        :param include_user: The include_user of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_user = include_user

    @property
    def include_user_group(self):
        """Gets the include_user_group of this SearchEntitiesOptions.  # noqa: E501


        :return: The include_user_group of this SearchEntitiesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_user_group

    @include_user_group.setter
    def include_user_group(self, include_user_group):
        """Sets the include_user_group of this SearchEntitiesOptions.


        :param include_user_group: The include_user_group of this SearchEntitiesOptions.  # noqa: E501
        :type: bool
        """

        self._include_user_group = include_user_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchEntitiesOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchEntitiesOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class UpdateMachineAssignedItemInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'md_item_id': 'int',
        'assigned_item_id': 'int',
        'is_installed': 'bool'
    }

    attribute_map = {
        'md_item_id': 'mdItemId',
        'assigned_item_id': 'assignedItemId',
        'is_installed': 'isInstalled'
    }

    def __init__(self, md_item_id=None, assigned_item_id=None, is_installed=None, local_vars_configuration=None):  # noqa: E501
        """UpdateMachineAssignedItemInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._md_item_id = None
        self._assigned_item_id = None
        self._is_installed = None
        self.discriminator = None

        if md_item_id is not None:
            self.md_item_id = md_item_id
        if assigned_item_id is not None:
            self.assigned_item_id = assigned_item_id
        if is_installed is not None:
            self.is_installed = is_installed

    @property
    def md_item_id(self):
        """Gets the md_item_id of this UpdateMachineAssignedItemInformation.  # noqa: E501


        :return: The md_item_id of this UpdateMachineAssignedItemInformation.  # noqa: E501
        :rtype: int
        """
        return self._md_item_id

    @md_item_id.setter
    def md_item_id(self, md_item_id):
        """Sets the md_item_id of this UpdateMachineAssignedItemInformation.


        :param md_item_id: The md_item_id of this UpdateMachineAssignedItemInformation.  # noqa: E501
        :type: int
        """

        self._md_item_id = md_item_id

    @property
    def assigned_item_id(self):
        """Gets the assigned_item_id of this UpdateMachineAssignedItemInformation.  # noqa: E501


        :return: The assigned_item_id of this UpdateMachineAssignedItemInformation.  # noqa: E501
        :rtype: int
        """
        return self._assigned_item_id

    @assigned_item_id.setter
    def assigned_item_id(self, assigned_item_id):
        """Sets the assigned_item_id of this UpdateMachineAssignedItemInformation.


        :param assigned_item_id: The assigned_item_id of this UpdateMachineAssignedItemInformation.  # noqa: E501
        :type: int
        """

        self._assigned_item_id = assigned_item_id

    @property
    def is_installed(self):
        """Gets the is_installed of this UpdateMachineAssignedItemInformation.  # noqa: E501


        :return: The is_installed of this UpdateMachineAssignedItemInformation.  # noqa: E501
        :rtype: bool
        """
        return self._is_installed

    @is_installed.setter
    def is_installed(self, is_installed):
        """Sets the is_installed of this UpdateMachineAssignedItemInformation.


        :param is_installed: The is_installed of this UpdateMachineAssignedItemInformation.  # noqa: E501
        :type: bool
        """

        self._is_installed = is_installed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateMachineAssignedItemInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateMachineAssignedItemInformation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class ItemResource(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'value': 'str',
        'units': 'str',
        'description': 'str',
        'is_provided': 'bool',
        'is_used_required': 'bool',
        'is_used_optional': 'bool',
        'item': 'Item',
        'resource_type': 'ResourceType',
        'item_connector': 'ItemConnector'
    }

    attribute_map = {
        'id': 'id',
        'value': 'value',
        'units': 'units',
        'description': 'description',
        'is_provided': 'isProvided',
        'is_used_required': 'isUsedRequired',
        'is_used_optional': 'isUsedOptional',
        'item': 'item',
        'resource_type': 'resourceType',
        'item_connector': 'itemConnector'
    }

    def __init__(self, id=None, value=None, units=None, description=None, is_provided=None, is_used_required=None, is_used_optional=None, item=None, resource_type=None, item_connector=None, local_vars_configuration=None):  # noqa: E501
        """ItemResource - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._value = None
        self._units = None
        self._description = None
        self._is_provided = None
        self._is_used_required = None
        self._is_used_optional = None
        self._item = None
        self._resource_type = None
        self._item_connector = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if value is not None:
            self.value = value
        if units is not None:
            self.units = units
        if description is not None:
            self.description = description
        if is_provided is not None:
            self.is_provided = is_provided
        if is_used_required is not None:
            self.is_used_required = is_used_required
        if is_used_optional is not None:
            self.is_used_optional = is_used_optional
        if item is not None:
            self.item = item
        if resource_type is not None:
            self.resource_type = resource_type
        if item_connector is not None:
            self.item_connector = item_connector

    @property
    def id(self):
        """Gets the id of this ItemResource.  # noqa: E501


        :return: The id of this ItemResource.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ItemResource.


        :param id: The id of this ItemResource.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def value(self):
        """Gets the value of this ItemResource.  # noqa: E501


        :return: The value of this ItemResource.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ItemResource.


        :param value: The value of this ItemResource.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                value is not None and len(value) > 64):
            raise ValueError("Invalid value for `value`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                value is not None and len(value) < 0):
            raise ValueError("Invalid value for `value`, length must be greater than or equal to `0`")  # noqa: E501

        self._value = value

    @property
    def units(self):
        """Gets the units of this ItemResource.  # noqa: E501


        :return: The units of this ItemResource.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this ItemResource.


        :param units: The units of this ItemResource.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                units is not None and len(units) > 64):
            raise ValueError("Invalid value for `units`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                units is not None and len(units) < 0):
            raise ValueError("Invalid value for `units`, length must be greater than or equal to `0`")  # noqa: E501

        self._units = units

    @property
    def description(self):
        """Gets the description of this ItemResource.  # noqa: E501


        :return: The description of this ItemResource.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ItemResource.


        :param description: The description of this ItemResource.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 256):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def is_provided(self):
        """Gets the is_provided of this ItemResource.  # noqa: E501


        :return: The is_provided of this ItemResource.  # noqa: E501
        :rtype: bool
        """
        return self._is_provided

    @is_provided.setter
    def is_provided(self, is_provided):
        """Sets the is_provided of this ItemResource.


        :param is_provided: The is_provided of this ItemResource.  # noqa: E501
        :type: bool
        """

        self._is_provided = is_provided

    @property
    def is_used_required(self):
        """Gets the is_used_required of this ItemResource.  # noqa: E501


        :return: The is_used_required of this ItemResource.  # noqa: E501
        :rtype: bool
        """
        return self._is_used_required

    @is_used_required.setter
    def is_used_required(self, is_used_required):
        """Sets the is_used_required of this ItemResource.


        :param is_used_required: The is_used_required of this ItemResource.  # noqa: E501
        :type: bool
        """

        self._is_used_required = is_used_required

    @property
    def is_used_optional(self):
        """Gets the is_used_optional of this ItemResource.  # noqa: E501


        :return: The is_used_optional of this ItemResource.  # noqa: E501
        :rtype: bool
        """
        return self._is_used_optional

    @is_used_optional.setter
    def is_used_optional(self, is_used_optional):
        """Sets the is_used_optional of this ItemResource.


        :param is_used_optional: The is_used_optional of this ItemResource.  # noqa: E501
        :type: bool
        """

        self._is_used_optional = is_used_optional

    @property
    def item(self):
        """Gets the item of this ItemResource.  # noqa: E501


        :return: The item of this ItemResource.  # noqa: E501
        :rtype: Item
        """
        return self._item

    @item.setter
    def item(self, item):
        """Sets the item of this ItemResource.


        :param item: The item of this ItemResource.  # noqa: E501
        :type: Item
        """

        self._item = item

    @property
    def resource_type(self):
        """Gets the resource_type of this ItemResource.  # noqa: E501


        :return: The resource_type of this ItemResource.  # noqa: E501
        :rtype: ResourceType
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this ItemResource.


        :param resource_type: The resource_type of this ItemResource.  # noqa: E501
        :type: ResourceType
        """

        self._resource_type = resource_type

    @property
    def item_connector(self):
        """Gets the item_connector of this ItemResource.  # noqa: E501


        :return: The item_connector of this ItemResource.  # noqa: E501
        :rtype: ItemConnector
        """
        return self._item_connector

    @item_connector.setter
    def item_connector(self, item_connector):
        """Sets the item_connector of this ItemResource.


        :param item_connector: The item_connector of this ItemResource.  # noqa: E501
        :type: ItemConnector
        """

        self._item_connector = item_connector

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemResource):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemResource):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class ListTbl(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'description': 'str',
        'item_element_list': 'list[ItemElement]',
        'user_info_list': 'list[UserInfo]',
        'user_group_list': 'list[UserGroup]',
        'entity_info': 'EntityInfo'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'item_element_list': 'itemElementList',
        'user_info_list': 'userInfoList',
        'user_group_list': 'userGroupList',
        'entity_info': 'entityInfo'
    }

    def __init__(self, id=None, name=None, description=None, item_element_list=None, user_info_list=None, user_group_list=None, entity_info=None, local_vars_configuration=None):  # noqa: E501
        """ListTbl - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._description = None
        self._item_element_list = None
        self._user_info_list = None
        self._user_group_list = None
        self._entity_info = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        if description is not None:
            self.description = description
        if item_element_list is not None:
            self.item_element_list = item_element_list
        if user_info_list is not None:
            self.user_info_list = user_info_list
        if user_group_list is not None:
            self.user_group_list = user_group_list
        if entity_info is not None:
            self.entity_info = entity_info

    @property
    def id(self):
        """Gets the id of this ListTbl.  # noqa: E501


        :return: The id of this ListTbl.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ListTbl.


        :param id: The id of this ListTbl.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ListTbl.  # noqa: E501


        :return: The name of this ListTbl.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ListTbl.


        :param name: The name of this ListTbl.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 64):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this ListTbl.  # noqa: E501


        :return: The description of this ListTbl.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ListTbl.


        :param description: The description of this ListTbl.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 256):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def item_element_list(self):
        """Gets the item_element_list of this ListTbl.  # noqa: E501


        :return: The item_element_list of this ListTbl.  # noqa: E501
        :rtype: list[ItemElement]
        """
        return self._item_element_list

    @item_element_list.setter
    def item_element_list(self, item_element_list):
        """Sets the item_element_list of this ListTbl.


        :param item_element_list: The item_element_list of this ListTbl.  # noqa: E501
        :type: list[ItemElement]
        """

        self._item_element_list = item_element_list

    @property
    def user_info_list(self):
        """Gets the user_info_list of this ListTbl.  # noqa: E501


        :return: The user_info_list of this ListTbl.  # noqa: E501
        :rtype: list[UserInfo]
        """
        return self._user_info_list

    @user_info_list.setter
    def user_info_list(self, user_info_list):
        """Sets the user_info_list of this ListTbl.


        :param user_info_list: The user_info_list of this ListTbl.  # noqa: E501
        :type: list[UserInfo]
        """

        self._user_info_list = user_info_list

    @property
    def user_group_list(self):
        """Gets the user_group_list of this ListTbl.  # noqa: E501


        :return: The user_group_list of this ListTbl.  # noqa: E501
        :rtype: list[UserGroup]
        """
        return self._user_group_list

    @user_group_list.setter
    def user_group_list(self, user_group_list):
        """Sets the user_group_list of this ListTbl.


        :param user_group_list: The user_group_list of this ListTbl.  # noqa: E501
        :type: list[UserGroup]
        """

        self._user_group_list = user_group_list

    @property
    def entity_info(self):
        """Gets the entity_info of this ListTbl.  # noqa: E501


        :return: The entity_info of this ListTbl.  # noqa: E501
        :rtype: EntityInfo
        """
        return self._entity_info

    @entity_info.setter
    def entity_info(self, entity_info):
        """Sets the entity_info of this ListTbl.


        :param entity_info: The entity_info of this ListTbl.  # noqa: E501
        :type: EntityInfo
        """

        self._entity_info = entity_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTbl):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListTbl):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class PropertyValueHistory(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'tag': 'str',
        'value': 'str',
        'units': 'str',
        'description': 'str',
        'entered_on_date_time': 'datetime',
        'effective_from_date_time': 'datetime',
        'effective_to_date_time': 'datetime',
        'display_value': 'str',
        'target_value': 'str',
        'entered_by_user': 'UserInfo'
    }

    attribute_map = {
        'id': 'id',
        'tag': 'tag',
        'value': 'value',
        'units': 'units',
        'description': 'description',
        'entered_on_date_time': 'enteredOnDateTime',
        'effective_from_date_time': 'effectiveFromDateTime',
        'effective_to_date_time': 'effectiveToDateTime',
        'display_value': 'displayValue',
        'target_value': 'targetValue',
        'entered_by_user': 'enteredByUser'
    }

    def __init__(self, id=None, tag=None, value=None, units=None, description=None, entered_on_date_time=None, effective_from_date_time=None, effective_to_date_time=None, display_value=None, target_value=None, entered_by_user=None, local_vars_configuration=None):  # noqa: E501
        """PropertyValueHistory - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._tag = None
        self._value = None
        self._units = None
        self._description = None
        self._entered_on_date_time = None
        self._effective_from_date_time = None
        self._effective_to_date_time = None
        self._display_value = None
        self._target_value = None
        self._entered_by_user = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if tag is not None:
            self.tag = tag
        if value is not None:
            self.value = value
        if units is not None:
            self.units = units
        if description is not None:
            self.description = description
        self.entered_on_date_time = entered_on_date_time
        if effective_from_date_time is not None:
            self.effective_from_date_time = effective_from_date_time
        if effective_to_date_time is not None:
            self.effective_to_date_time = effective_to_date_time
        if display_value is not None:
            self.display_value = display_value
        if target_value is not None:
            self.target_value = target_value
        if entered_by_user is not None:
            self.entered_by_user = entered_by_user

    @property
    def id(self):
        """Gets the id of this PropertyValueHistory.  # noqa: E501


        :return: The id of this PropertyValueHistory.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PropertyValueHistory.


        :param id: The id of this PropertyValueHistory.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def tag(self):
        """Gets the tag of this PropertyValueHistory.  # noqa: E501


        :return: The tag of this PropertyValueHistory.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this PropertyValueHistory.


        :param tag: The tag of this PropertyValueHistory.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                tag is not None and len(tag) > 64):
            raise ValueError("Invalid value for `tag`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                tag is not None and len(tag) < 0):
            raise ValueError("Invalid value for `tag`, length must be greater than or equal to `0`")  # noqa: E501

        self._tag = tag

    @property
    def value(self):
        """Gets the value of this PropertyValueHistory.  # noqa: E501


        :return: The value of this PropertyValueHistory.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this PropertyValueHistory.


        :param value: The value of this PropertyValueHistory.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                value is not None and len(value) > 256):
            raise ValueError("Invalid value for `value`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                value is not None and len(value) < 0):
            raise ValueError("Invalid value for `value`, length must be greater than or equal to `0`")  # noqa: E501

        self._value = value

    @property
    def units(self):
        """Gets the units of this PropertyValueHistory.  # noqa: E501


        :return: The units of this PropertyValueHistory.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this PropertyValueHistory.


        :param units: The units of this PropertyValueHistory.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                units is not None and len(units) > 16):
            raise ValueError("Invalid value for `units`, length must be less than or equal to `16`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                units is not None and len(units) < 0):
            raise ValueError("Invalid value for `units`, length must be greater than or equal to `0`")  # noqa: E501

        self._units = units

    @property
    def description(self):
        """Gets the description of this PropertyValueHistory.  # noqa: E501


        :return: The description of this PropertyValueHistory.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PropertyValueHistory.


        :param description: The description of this PropertyValueHistory.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 256):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def entered_on_date_time(self):
        """Gets the entered_on_date_time of this PropertyValueHistory.  # noqa: E501


        :return: The entered_on_date_time of this PropertyValueHistory.  # noqa: E501
        :rtype: datetime
        """
        return self._entered_on_date_time

    @entered_on_date_time.setter
    def entered_on_date_time(self, entered_on_date_time):
        """Sets the entered_on_date_time of this PropertyValueHistory.


        :param entered_on_date_time: The entered_on_date_time of this PropertyValueHistory.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and entered_on_date_time is None:  # noqa: E501
            raise ValueError("Invalid value for `entered_on_date_time`, must not be `None`")  # noqa: E501

        self._entered_on_date_time = entered_on_date_time

    @property
    def effective_from_date_time(self):
        """Gets the effective_from_date_time of this PropertyValueHistory.  # noqa: E501


        :return: The effective_from_date_time of this PropertyValueHistory.  # noqa: E501
        :rtype: datetime
        """
        return self._effective_from_date_time

    @effective_from_date_time.setter
    def effective_from_date_time(self, effective_from_date_time):
        """Sets the effective_from_date_time of this PropertyValueHistory.


        :param effective_from_date_time: The effective_from_date_time of this PropertyValueHistory.  # noqa: E501
        :type: datetime
        """

        self._effective_from_date_time = effective_from_date_time

    @property
    def effective_to_date_time(self):
        """Gets the effective_to_date_time of this PropertyValueHistory.  # noqa: E501


        :return: The effective_to_date_time of this PropertyValueHistory.  # noqa: E501
        :rtype: datetime
        """
        return self._effective_to_date_time

    @effective_to_date_time.setter
    def effective_to_date_time(self, effective_to_date_time):
        """Sets the effective_to_date_time of this PropertyValueHistory.


        :param effective_to_date_time: The effective_to_date_time of this PropertyValueHistory.  # noqa: E501
        :type: datetime
        """

        self._effective_to_date_time = effective_to_date_time

    @property
    def display_value(self):
        """Gets the display_value of this PropertyValueHistory.  # noqa: E501


        :return: The display_value of this PropertyValueHistory.  # noqa: E501
        :rtype: str
        """
        return self._display_value

    @display_value.setter
    def display_value(self, display_value):
        """Sets the display_value of this PropertyValueHistory.


        :param display_value: The display_value of this PropertyValueHistory.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                display_value is not None and len(display_value) > 256):
            raise ValueError("Invalid value for `display_value`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                display_value is not None and len(display_value) < 0):
            raise ValueError("Invalid value for `display_value`, length must be greater than or equal to `0`")  # noqa: E501

        self._display_value = display_value

    @property
    def target_value(self):
        """Gets the target_value of this PropertyValueHistory.  # noqa: E501


        :return: The target_value of this PropertyValueHistory.  # noqa: E501
        :rtype: str
        """
        return self._target_value

    @target_value.setter
    def target_value(self, target_value):
        """Sets the target_value of this PropertyValueHistory.


        :param target_value: The target_value of this PropertyValueHistory.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                target_value is not None and len(target_value) > 256):
            raise ValueError("Invalid value for `target_value`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                target_value is not None and len(target_value) < 0):
            raise ValueError("Invalid value for `target_value`, length must be greater than or equal to `0`")  # noqa: E501

        self._target_value = target_value

    @property
    def entered_by_user(self):
        """Gets the entered_by_user of this PropertyValueHistory.  # noqa: E501


        :return: The entered_by_user of this PropertyValueHistory.  # noqa: E501
        :rtype: UserInfo
        """
        return self._entered_by_user

    @entered_by_user.setter
    def entered_by_user(self, entered_by_user):
        """Sets the entered_by_user of this PropertyValueHistory.


        :param entered_by_user: The entered_by_user of this PropertyValueHistory.  # noqa: E501
        :type: UserInfo
        """

        self._entered_by_user = entered_by_user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PropertyValueHistory):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PropertyValueHistory):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class ItemDomainCableDesignAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alternate_name': 'str',
        'assigned_item': 'Item',
        'is_housed': 'bool',
        'catalog_item': 'ItemDomainCableCatalog',
        'inventory_item': 'ItemDomainCableInventory',
        'technical_system_list': 'list[ItemCategory]'
    }

    attribute_map = {
        'alternate_name': 'alternateName',
        'assigned_item': 'assignedItem',
        'is_housed': 'isHoused',
        'catalog_item': 'catalogItem',
        'inventory_item': 'inventoryItem',
        'technical_system_list': 'technicalSystemList'
    }

    def __init__(self, alternate_name=None, assigned_item=None, is_housed=None, catalog_item=None, inventory_item=None, technical_system_list=None, local_vars_configuration=None):  # noqa: E501
        """ItemDomainCableDesignAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alternate_name = None
        self._assigned_item = None
        self._is_housed = None
        self._catalog_item = None
        self._inventory_item = None
        self._technical_system_list = None
        self.discriminator = None

        if alternate_name is not None:
            self.alternate_name = alternate_name
        if assigned_item is not None:
            self.assigned_item = assigned_item
        if is_housed is not None:
            self.is_housed = is_housed
        if catalog_item is not None:
            self.catalog_item = catalog_item
        if inventory_item is not None:
            self.inventory_item = inventory_item
        if technical_system_list is not None:
            self.technical_system_list = technical_system_list

    @property
    def alternate_name(self):
        """Gets the alternate_name of this ItemDomainCableDesignAllOf.  # noqa: E501


        :return: The alternate_name of this ItemDomainCableDesignAllOf.  # noqa: E501
        :rtype: str
        """
        return self._alternate_name

    @alternate_name.setter
    def alternate_name(self, alternate_name):
        """Sets the alternate_name of this ItemDomainCableDesignAllOf.


        :param alternate_name: The alternate_name of this ItemDomainCableDesignAllOf.  # noqa: E501
        :type: str
        """

        self._alternate_name = alternate_name

    @property
    def assigned_item(self):
        """Gets the assigned_item of this ItemDomainCableDesignAllOf.  # noqa: E501


        :return: The assigned_item of this ItemDomainCableDesignAllOf.  # noqa: E501
        :rtype: Item
        """
        return self._assigned_item

    @assigned_item.setter
    def assigned_item(self, assigned_item):
        """Sets the assigned_item of this ItemDomainCableDesignAllOf.


        :param assigned_item: The assigned_item of this ItemDomainCableDesignAllOf.  # noqa: E501
        :type: Item
        """

        self._assigned_item = assigned_item

    @property
    def is_housed(self):
        """Gets the is_housed of this ItemDomainCableDesignAllOf.  # noqa: E501


        :return: The is_housed of this ItemDomainCableDesignAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._is_housed

    @is_housed.setter
    def is_housed(self, is_housed):
        """Sets the is_housed of this ItemDomainCableDesignAllOf.


        :param is_housed: The is_housed of this ItemDomainCableDesignAllOf.  # noqa: E501
        :type: bool
        """

        self._is_housed = is_housed

    @property
    def catalog_item(self):
        """Gets the catalog_item of this ItemDomainCableDesignAllOf.  # noqa: E501


        :return: The catalog_item of this ItemDomainCableDesignAllOf.  # noqa: E501
        :rtype: ItemDomainCableCatalog
        """
        return self._catalog_item

    @catalog_item.setter
    def catalog_item(self, catalog_item):
        """Sets the catalog_item of this ItemDomainCableDesignAllOf.


        :param catalog_item: The catalog_item of this ItemDomainCableDesignAllOf.  # noqa: E501
        :type: ItemDomainCableCatalog
        """

        self._catalog_item = catalog_item

    @property
    def inventory_item(self):
        """Gets the inventory_item of this ItemDomainCableDesignAllOf.  # noqa: E501


        :return: The inventory_item of this ItemDomainCableDesignAllOf.  # noqa: E501
        :rtype: ItemDomainCableInventory
        """
        return self._inventory_item

    @inventory_item.setter
    def inventory_item(self, inventory_item):
        """Sets the inventory_item of this ItemDomainCableDesignAllOf.


        :param inventory_item: The inventory_item of this ItemDomainCableDesignAllOf.  # noqa: E501
        :type: ItemDomainCableInventory
        """

        self._inventory_item = inventory_item

    @property
    def technical_system_list(self):
        """Gets the technical_system_list of this ItemDomainCableDesignAllOf.  # noqa: E501


        :return: The technical_system_list of this ItemDomainCableDesignAllOf.  # noqa: E501
        :rtype: list[ItemCategory]
        """
        return self._technical_system_list

    @technical_system_list.setter
    def technical_system_list(self, technical_system_list):
        """Sets the technical_system_list of this ItemDomainCableDesignAllOf.


        :param technical_system_list: The technical_system_list of this ItemDomainCableDesignAllOf.  # noqa: E501
        :type: list[ItemCategory]
        """

        self._technical_system_list = technical_system_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemDomainCableDesignAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemDomainCableDesignAllOf):
            return True

        return self.to_dict() != other.to_dict()
